@@ -5,28 +5,28 @@ from featuretools.tests.testing_utils import backward_path
 from featuretools.utils import Trie
 
 
-def test_feature_trie_without_needs_full_entity(diamond_es):
+def test_feature_trie_without_needs_full_dataframe(diamond_es):
     es = diamond_es
-    country_name = ft.IdentityFeature(es['countries']['name'])
-    direct_name = ft.DirectFeature(country_name, es['regions'])
-    amount = ft.IdentityFeature(es['transactions']['amount'])
+    country_name = ft.IdentityFeature(es['countries'].ww['name'])
+    direct_name = ft.DirectFeature(country_name, 'regions')
+    amount = ft.IdentityFeature(es['transactions'].ww['amount'])
 
     path_through_customers = backward_path(es, ['regions', 'customers', 'transactions'])
-    through_customers = ft.AggregationFeature(amount, es['regions'],
+    through_customers = ft.AggregationFeature(amount, 'regions',
                                               primitive=ft.primitives.Mean,
                                               relationship_path=path_through_customers)
     path_through_stores = backward_path(es, ['regions', 'stores', 'transactions'])
-    through_stores = ft.AggregationFeature(amount, es['regions'],
+    through_stores = ft.AggregationFeature(amount, 'regions',
                                            primitive=ft.primitives.Mean,
                                            relationship_path=path_through_stores)
     customers_to_transactions = backward_path(es, ['customers', 'transactions'])
-    customers_mean = ft.AggregationFeature(amount, es['customers'],
+    customers_mean = ft.AggregationFeature(amount, 'customers',
                                            primitive=ft.primitives.Mean,
                                            relationship_path=customers_to_transactions)
 
     negation = ft.TransformFeature(customers_mean, ft.primitives.Negate)
     regions_to_customers = backward_path(es, ['regions', 'customers'])
-    mean_of_mean = ft.AggregationFeature(negation, es['regions'],
+    mean_of_mean = ft.AggregationFeature(negation, 'regions',
                                          primitive=ft.primitives.Mean,
                                          relationship_path=regions_to_customers)
 
@@ -49,19 +49,19 @@ def test_feature_trie_without_needs_full_entity(diamond_es):
         (False, set(), {amount.unique_name()})
 
 
-def test_feature_trie_with_needs_full_entity(diamond_es):
+def test_feature_trie_with_needs_full_dataframe(diamond_es):
     pd_es = diamond_es
-    amount = ft.IdentityFeature(pd_es['transactions']['amount'])
+    amount = ft.IdentityFeature(pd_es['transactions'].ww['amount'])
 
     path_through_customers = backward_path(pd_es, ['regions', 'customers', 'transactions'])
-    agg = ft.AggregationFeature(amount, pd_es['regions'],
+    agg = ft.AggregationFeature(amount, 'regions',
                                 primitive=ft.primitives.Mean,
                                 relationship_path=path_through_customers)
     trans_of_agg = ft.TransformFeature(agg, ft.primitives.CumSum)
 
     path_through_stores = backward_path(pd_es, ['regions', 'stores', 'transactions'])
     trans = ft.TransformFeature(amount, ft.primitives.CumSum)
-    agg_of_trans = ft.AggregationFeature(trans, pd_es['regions'],
+    agg_of_trans = ft.AggregationFeature(trans, 'regions',
                                          primitive=ft.primitives.Mean,
                                          relationship_path=path_through_stores)
 
@@ -79,13 +79,13 @@ def test_feature_trie_with_needs_full_entity(diamond_es):
     assert trie.get_node(path_through_stores[:1]).value == (False, set(), set())
 
 
-def test_feature_trie_with_needs_full_entity_direct(es):
-    value = ft.IdentityFeature(es['log']['value'],)
-    agg = ft.AggregationFeature(value, es['sessions'],
+def test_feature_trie_with_needs_full_dataframe_direct(es):
+    value = ft.IdentityFeature(es['log'].ww['value'])
+    agg = ft.AggregationFeature(value, 'sessions',
                                 primitive=ft.primitives.Mean)
-    agg_of_agg = ft.AggregationFeature(agg, es['customers'],
+    agg_of_agg = ft.AggregationFeature(agg, 'customers',
                                        primitive=ft.primitives.Sum)
-    direct = ft.DirectFeature(agg_of_agg, es['sessions'])
+    direct = ft.DirectFeature(agg_of_agg, 'sessions')
     trans = ft.TransformFeature(direct, ft.primitives.CumSum)
 
     features = [trans, agg]
@@ -109,12 +109,12 @@ def test_feature_trie_with_needs_full_entity_direct(es):
 
 
 def test_feature_trie_ignores_approximate_features(es):
-    value = ft.IdentityFeature(es['log']['value'],)
-    agg = ft.AggregationFeature(value, es['sessions'],
+    value = ft.IdentityFeature(es['log'].ww['value'])
+    agg = ft.AggregationFeature(value, 'sessions',
                                 primitive=ft.primitives.Mean)
-    agg_of_agg = ft.AggregationFeature(agg, es['customers'],
+    agg_of_agg = ft.AggregationFeature(agg, 'customers',
                                        primitive=ft.primitives.Sum)
-    direct = ft.DirectFeature(agg_of_agg, es['sessions'])
+    direct = ft.DirectFeature(agg_of_agg, 'sessions')
     features = [direct, agg]
 
     approximate_feature_trie = Trie(default=list, path_constructor=RelationshipPath)
