@@ -25,7 +25,7 @@ def cluster_scheduler():
 @pytest.fixture()
 def three_worker_scheduler():
     with cluster(nworkers=3) as (scheduler, [a, b, c]):
-        yield scheduler
+        yield scheduler  # pragma: no cover
 
 
 @pytest.fixture(scope='session', autouse=True)
@@ -394,7 +394,7 @@ def lt(es):
         return df['value'].sum() > 10
 
     lm = cp.LabelMaker(
-        target_entity='id',
+        target_dataframe_name='id',
         time_index='datetime',
         labeling_function=label_func,
         window_size='1m'
