@@ -4,11 +4,11 @@ import featuretools as ft
 from featuretools.entityset.deserialize import description_to_entityset
 from featuretools.feature_base.features_serializer import FeaturesSerializer
 
-SCHEMA_VERSION = "6.0.0"
+SCHEMA_VERSION = "7.0.0"
 
 
 def test_single_feature(es):
-    feature = ft.IdentityFeature(es['log']['value'])
+    feature = ft.IdentityFeature(es['log'].ww['value'])
     serializer = FeaturesSerializer([feature])
 
     expected = {
@@ -25,8 +25,8 @@ def test_single_feature(es):
 
 
 def test_base_features_in_list(es):
-    value = ft.IdentityFeature(es['log']['value'])
-    max_feature = ft.AggregationFeature(value, es['sessions'], ft.primitives.Max)
+    value = ft.IdentityFeature(es['log'].ww['value'])
+    max_feature = ft.AggregationFeature(value, 'sessions', ft.primitives.Max)
     features = [max_feature, value]
     serializer = FeaturesSerializer(features)
 
@@ -45,14 +45,14 @@ def test_base_features_in_list(es):
 
 
 def test_multi_output_features(es):
-    value = ft.IdentityFeature(es['log']['product_id'])
+    product_id = ft.IdentityFeature(es['log'].ww['product_id'])
     threecommon = ft.primitives.NMostCommon()
-    tc = ft.Feature(es['log']['product_id'], parent_entity=es["sessions"], primitive=threecommon)
+    tc = ft.Feature(product_id, parent_dataframe_name="sessions", primitive=threecommon)
 
-    features = [tc, value]
+    features = [tc, product_id]
     for i in range(3):
         features.append(ft.Feature(tc[i],
-                                   parent_entity=es['customers'],
+                                   parent_dataframe_name='customers',
                                    primitive=ft.primitives.NumUnique))
         features.append(tc[i])
 
@@ -75,10 +75,10 @@ def test_multi_output_features(es):
 
 
 def test_base_features_not_in_list(es):
-    value = ft.IdentityFeature(es['log']['value'])
+    value = ft.IdentityFeature(es['log'].ww['value'])
     value_x2 = ft.TransformFeature(value,
                                    ft.primitives.MultiplyNumericScalar(value=2))
-    max_feature = ft.AggregationFeature(value_x2, es['sessions'], ft.primitives.Max)
+    max_feature = ft.AggregationFeature(value_x2, 'sessions', ft.primitives.Max)
     features = [max_feature]
     serializer = FeaturesSerializer(features)
 
@@ -98,9 +98,9 @@ def test_base_features_not_in_list(es):
 
 
 def test_where_feature_dependency(es):
-    value = ft.IdentityFeature(es['log']['value'])
-    is_purchased = ft.IdentityFeature(es['log']['purchased'])
-    max_feature = ft.AggregationFeature(value, es['sessions'], ft.primitives.Max,
+    value = ft.IdentityFeature(es['log'].ww['value'])
+    is_purchased = ft.IdentityFeature(es['log'].ww['purchased'])
+    max_feature = ft.AggregationFeature(value, 'sessions', ft.primitives.Max,
                                         where=is_purchased)
     features = [max_feature]
     serializer = FeaturesSerializer(features)
@@ -121,9 +121,9 @@ def test_where_feature_dependency(es):
 
 
 def test_feature_use_previous_pd_timedelta(es):
-    value = ft.IdentityFeature(es['log']['id'])
+    value = ft.IdentityFeature(es['log'].ww['id'])
     td = pd.Timedelta(12, "W")
-    count_feature = ft.AggregationFeature(value, es['customers'], ft.primitives.Count, use_previous=td)
+    count_feature = ft.AggregationFeature(value, 'customers', ft.primitives.Count, use_previous=td)
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
 
@@ -142,9 +142,9 @@ def test_feature_use_previous_pd_timedelta(es):
 
 
 def test_feature_use_previous_pd_dateoffset(es):
-    value = ft.IdentityFeature(es['log']['id'])
+    value = ft.IdentityFeature(es['log'].ww['id'])
     do = pd.DateOffset(months=3)
-    count_feature = ft.AggregationFeature(value, es['customers'], ft.primitives.Count, use_previous=do)
+    count_feature = ft.AggregationFeature(value, 'customers', ft.primitives.Count, use_previous=do)
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
 
@@ -161,9 +161,9 @@ def test_feature_use_previous_pd_dateoffset(es):
 
     _compare_feature_dicts(expected, serializer.to_dict())
 
-    value = ft.IdentityFeature(es['log']['id'])
+    value = ft.IdentityFeature(es['log'].ww['id'])
     do = pd.DateOffset(months=3, days=2, minutes=30)
-    count_feature = ft.AggregationFeature(value, es['customers'], ft.primitives.Count, use_previous=do)
+    count_feature = ft.AggregationFeature(value, 'customers', ft.primitives.Count, use_previous=do)
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
 
@@ -182,7 +182,7 @@ def test_feature_use_previous_pd_dateoffset(es):
 
 
 def _compare_feature_dicts(a_dict, b_dict):
-    # We can't compare entityset dictionaries because variable lists are not
+    # We can't compare entityset dictionaries because column lists are not
     # guaranteed to be in the same order.
     es_a = description_to_entityset(a_dict.pop('entityset'))
     es_b = description_to_entityset(b_dict.pop('entityset'))
