@@ -2,4 +2,4 @@
 from .mock_ds import make_ecommerce_entityset
 from .features import feature_with_name, backward_path, forward_path, check_rename, check_names
 from .cluster import MockClient, mock_cluster, get_mock_client_cluster
-from .es_utils import to_pandas
\ No newline at end of file
+from .es_utils import get_df_tags, to_pandas
